package com.cpxt.biz.service;

import com.cpxt.biz.domain.StatDriver;
import java.util.List;
import java.util.Map;

/**
 * 司机统计Service接口
 * 
 * @author ruoyi
 * @date 2024-12-31
 */
public interface IStatDriverService 
{
    /**
     * 查询司机统计
     * 
     * @param id 司机统计主键
     * @return 司机统计
     */
    public StatDriver selectStatDriverById(Long id);

    /**
     * 查询司机统计列表
     * 
     * @param statDriver 司机统计
     * @return 司机统计集合
     */
    public List<StatDriver> selectStatDriverList(StatDriver statDriver);

    /**
     * 新增司机统计
     * 
     * @param statDriver 司机统计
     * @return 结果
     */
    public int insertStatDriver(StatDriver statDriver);

    /**
     * 修改司机统计
     * 
     * @param statDriver 司机统计
     * @return 结果
     */
    public int updateStatDriver(StatDriver statDriver);

    /**
     * 批量删除司机统计
     * 
     * @param ids 需要删除的司机统计主键集合
     * @return 结果
     */
    public int deleteStatDriverByIds(Long[] ids);

    /**
     * 删除司机统计信息
     * 
     * @param id 司机统计主键
     * @return 结果
     */
    public int deleteStatDriverById(Long id);

    Map<String,Map<String,Object>> statics(StatDriver statDriver);

}
